@@ -1,11 +1,9 @@
 package Net::Hadoop::YARN;
-$Net::Hadoop::YARN::VERSION = '0.002';
+$Net::Hadoop::YARN::VERSION = '0.003';
 {
   $Net::Hadoop::YARN::DIST = 'Net-Hadoop-YARN';
 }
 
-# ABSTRACT: Communicate with Apache Hadoop NextGen MapReduce (YARN) 
-
 use strict;
 use warnings;
 use 5.10.0;
@@ -26,11 +24,25 @@ __END__
 
 =head1 NAME
 
-Net::Hadoop::YARN - Communicate with Apache Hadoop NextGen MapReduce (YARN) 
+Net::Hadoop::YARN
 
 =head1 VERSION
 
-version 0.002
+version 0.003
+
+=head1 SYNOPSIS
+
+TODO
+
+=cut
+
+=head1 DESCRIPTION
+
+TODO
+
+=head1 NAME
+
+Net::Hadoop::YARN - Perl interface to the YARN APIs
 
 =head1 AUTHOR
 
